#     db-manager - Builds and manages an OwlBoard database instance - To be run on a
#     cron schedule
#     Copyright (C) 2023  Frederick Boniface

#     This program is free software: you can redistribute it and/or modify it under the
#     terms of the GNU General Public License as published by the Free Software
#     Foundation, either version 3 of the License, or (at your option) any later version.

#     This program is distributed in the hope that it will be useful, but WITHOUT ANY
#     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
#     PARTICULAR PURPOSE.  See the GNU General Public License for more details.

#     You should have received a copy of the GNU General Public License along with this
#     program.  If not, see
#     https://git.fjla.uk/OwlBoard/db-manager/src/branch/main/LICENSE

version = "0.1.0"
print(f"main.py: Initialising db-manager v{version}")

#Third Party Imports
import os
import time

#Local Imports
import corpus, mongo
import logger as log

log.out("main.py: db-manager Initialised", "INFO")

#Check & Update corpus/stations:
  # If older than 12 days then update
corpusAge = int(time.time()) - mongo.metaCheckTime("corpus")
log.out(f'main.py: Corpus is {corpusAge}s old', "INFO")
if corpusAge > 1036800:
    log.out('main.py: Updating CORPUS data', "INFO")
    corpusData = corpus.removeEmpty(corpus.fetch())
    mongo.putBulkCorpus(corpusData)
else:
    log.out('main.py: Not updating CORPUS data', "INFO")

stationsAge = int(time.time()) - mongo.metaCheckTime("stations")
log.out(f'main.py: Stations is {stationsAge}s old', "INFO")
# While the source of stations data is CORPUS, this statement is based on corpusAge, when/if changing the source, it should be changed to use stationsAge
# if stationsAge is used now, there could be a situation where stationsAge tries to update but fails as corpusData doesn't exist.
if corpusAge > 1036800:
    log.out('main.py: Updating stations data', "INFO")
    stationData = corpus.onlyStations(corpusData)
    mongo.putBulkStations(stationData)
else:
    log.out('main.py: Not updating stations data', "INFO")

# END
log.out(f"main.py: db-manager v{version} Complete", "INFO")